pub enum DebugEventType {
OutOfBounds {
address: u64,
size: usize,
},
NanDetected {
register: String,
value: f64,
},
InfDetected {
register: String,
},
RaceCondition {
address: u64,
},
Assertion {
condition: String,
file: String,
line: u32,
},
Printf {
format: String,
},
Breakpoint {
id: u32,
},
}Expand description
The kind of debug event captured during kernel execution.
Variants
OutOfBounds
A memory access was out of the allocated bounds.
NanDetected
A NaN was detected in a floating-point register.
Fields
InfDetected
An infinity was detected in a floating-point register.
RaceCondition
A potential race condition on a shared memory address.
Assertion
A kernel-side assertion.
Fields
Printf
A kernel-side printf invocation.
Breakpoint
A breakpoint was hit.