CUjit_option

Enum CUjit_option 

#[non_exhaustive]
#[repr(u32)]
pub enum CUjit_option {
Show 31 variants MaxRegisters = 0, ThreadsPerBlock = 1, WallTime = 2, InfoLogBuffer = 3, InfoLogBufferSizeBytes = 4, ErrorLogBuffer = 5, ErrorLogBufferSizeBytes = 6, OptimizationLevel = 7, TargetFromCuContext = 8, Target = 9, FallbackStrategy = 10, GenerateDebugInfo = 11, LogVerbose = 12, GenerateLineInfo = 13, CacheMode = 14, Sm3xOpt = 15, FastCompile = 16, GlobalSymbolNames = 17, GlobalSymbolAddresses = 18, GlobalSymbolCount = 19, Lto = 20, Ftz = 21, PrecDiv = 22, PrecSqrt = 23, Fma = 24, ReferencedKernelNames = 25, ReferencedKernelCount = 26, ReferencedVariableNames = 27, ReferencedVariableCount = 28, OptimizeUnusedDeviceVariables = 29, PositionIndependentCode = 30,
}
JIT compilation options passed to cuModuleLoadDataEx and related functions.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MaxRegisters = 0

Maximum number of registers that a thread may use.



ThreadsPerBlock = 1

Number of threads per block for the JIT target.



WallTime = 2

Wall-clock time (ms) for compilation.



InfoLogBuffer = 3

Pointer to a buffer for info log output.



InfoLogBufferSizeBytes = 4

Size (bytes) of the info-log buffer.



ErrorLogBuffer = 5

Pointer to a buffer for error log output.



ErrorLogBufferSizeBytes = 6

Size (bytes) of the error-log buffer.



OptimizationLevel = 7

Optimisation level (0-4).



TargetFromCuContext = 8

Determines the target based on the current attached context.



Target = 9

Specific compute target (sm_XX).



FallbackStrategy = 10

Fallback strategy when exact match is not found.



GenerateDebugInfo = 11

Specifies whether to generate debug info.



LogVerbose = 12

Generate verbose log messages.



GenerateLineInfo = 13

Generate line-number information.



CacheMode = 14

Cache mode (on / off).



Sm3xOpt = 15

(Internal) New SM3X option.



FastCompile = 16

Fast compile flag.



GlobalSymbolNames = 17

Global symbol names.



GlobalSymbolAddresses = 18

Global symbol addresses.



GlobalSymbolCount = 19

Number of global symbols.



Lto = 20

LTO flag.



Ftz = 21

FTZ (flush-to-zero) flag.



PrecDiv = 22

Prec-div flag.



PrecSqrt = 23

Prec-sqrt flag.



Fma = 24

FMA flag.



ReferencedKernelNames = 25

Referenced kernel names.



ReferencedKernelCount = 26

Referenced kernel count.



ReferencedVariableNames = 27

Referenced variable names.



ReferencedVariableCount = 28

Referenced variable count.



OptimizeUnusedDeviceVariables = 29

Optimise unused device variables.



PositionIndependentCode = 30

Position-independent code.