#[non_exhaustive]#[repr(u32)]pub enum CUmemLocationType {
Invalid = 0,
Device = 1,
Host = 2,
HostNuma = 3,
HostNumaCurrent = 4,
}Expand description
Specifies the kind of location described by a CUmemLocation.
Mirrors CUmemLocationType in cuda.h. Used by the virtual-memory
management APIs to identify where a memory allocation resides or which
device should be granted access.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Invalid = 0
Invalid / uninitialised location type.
Device = 1
Location is a CUDA device (the id field is a device ordinal).
Host = 2
Location is the host (CPU) memory.
HostNuma = 3
Location is a specific NUMA node on the host.
HostNumaCurrent = 4
Location is the NUMA node currently bound to the calling thread.