#[non_exhaustive]#[repr(u32)]pub enum CUpointer_attribute {
Context = 1,
MemoryType = 2,
DevicePointer = 3,
HostPointer = 4,
IsManaged = 9,
DeviceOrdinal = 10,
}Expand description
Pointer attribute identifiers passed to cuPointerGetAttribute.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Context = 1
Query the CUDA context associated with a pointer.
MemoryType = 2
Query the memory type (host / device / unified) of a pointer.
DevicePointer = 3
Query the device pointer corresponding to a host pointer.
HostPointer = 4
Query the host pointer corresponding to a device pointer.
IsManaged = 9
Query whether the memory is managed (unified).
DeviceOrdinal = 10
Query the device ordinal for the pointer.