ClusterOccupancy

Struct ClusterOccupancy 

pub struct ClusterOccupancy;
Hopper+ thread block cluster occupancy estimation.

Implementations

Source

impl ClusterOccupancy

pub fn estimate_cluster_occupancy( calculator: &OccupancyCalculator, block_size: u32, cluster_size: u32, registers_per_thread: u32, shared_memory: u32, ) -> ClusterOccupancyEstimate

Estimate occupancy when blocks are grouped into clusters.

A cluster of cluster_size blocks must all reside on the same GPC (GPU Processing Cluster). This effectively reduces the number of independent blocks schedulable per SM.

Parameters
  • calculator — occupancy calculator with device info.
  • block_size — threads per block.
  • cluster_size — number of blocks per cluster.
  • registers_per_thread — registers per thread.
  • shared_memory — shared memory per block (bytes).