pub struct ProfilerGuard { /* private fields */ }Expand description
RAII guard that starts the CUDA profiler on creation and stops it on drop.
This is useful for scoping profiling to a specific block of code.
If the profiler fails to stop on drop, the error is silently ignored
(since Drop::drop cannot return errors).
Implementations
Sourceimpl ProfilerGuard
impl ProfilerGuard
Sourcepub fn start() -> CudaResult<Self>
pub fn start() -> CudaResult<Self>
Starts the CUDA profiler and returns a guard that will stop it on drop.
Errors
Returns an error if profiler_start() fails.