pub enum PoolAttribute {
ReuseFollowEventDependencies,
ReuseAllowOpportunistic,
ReuseAllowInternalDependencies,
ReleaseThreshold(u64),
ReservedMemCurrent,
ReservedMemHigh,
UsedMemCurrent,
UsedMemHigh,
}Expand description
Attributes that can be queried or set on a StreamMemoryPool.
Variants
ReuseFollowEventDependencies
Whether freed blocks can be reused by following event dependencies.
ReuseAllowOpportunistic
Whether freed blocks can be opportunistically reused (without ordering).
ReuseAllowInternalDependencies
Whether the pool may insert internal dependencies for reuse.
ReleaseThreshold(u64)
The release threshold in bytes.
ReservedMemCurrent
Current reserved memory (read-only query).
ReservedMemHigh
High-water mark of reserved memory.
UsedMemCurrent
Current used memory (read-only query).
UsedMemHigh
High-water mark of used memory.
Implementations