pub fn stream_alloc(size: usize, stream: u64) -> CudaResult<StreamAllocation>Expand description
Allocate memory on a stream using a shared, process-wide default pool for device 0.
Unlike a throwaway pool, the returned StreamAllocation stays accounted
for and can be returned to the same pool via stream_free.
Errors
Propagates errors from pool creation and allocation.