Context configuration: limits, cache config, and shared memory config.
These functions allow tuning per-context resource limits (stack size, heap size, etc.) and cache / shared memory policies.
Example
let stack = context_config::get_limit(CUlimit::StackSize)?;
println!("GPU thread stack size: {stack} bytes");
context_config::set_cache_config(context_config::CacheConfig::PreferL1)?;Enums
- Cache
Config - Preferred cache configuration for a CUDA context or function.
- Shared
MemConfig - Shared memory bank configuration.
Functions
- get_
cache_ config - Returns the current cache configuration for the active context.
- get_
limit - Returns the value of a context limit.
- get_
shared_ mem_ config - Returns the current shared memory configuration for the active context.
- set_
cache_ config - Sets the cache configuration for the active context.
- set_
limit - Sets the value of a context limit.
- set_
shared_ mem_ config - Sets the shared memory configuration for the active context.