DebugEventType

Enum DebugEventType 

pub enum DebugEventType {
    OutOfBounds {
        address: u64,
        size: usize,
    },
    NanDetected {
        register: String,
        value: f64,
    },
    InfDetected {
        register: String,
    },
    RaceCondition {
        address: u64,
    },
    Assertion {
        condition: String,
        file: String,
        line: u32,
    },
    Printf {
        format: String,
    },
    Breakpoint {
        id: u32,
    },
}
The kind of debug event captured during kernel execution.

Variants



OutOfBounds

A memory access was out of the allocated bounds.

Fields

address: u64

The faulting address.

size: usize

The size of the attempted access in bytes.



NanDetected

A NaN was detected in a floating-point register.

Fields

register: String

Register or variable name.

value: f64

The NaN bit-pattern reinterpreted as f64.



InfDetected

An infinity was detected in a floating-point register.

Fields

register: String

Register or variable name.



RaceCondition

A potential race condition on a shared memory address.

Fields

address: u64

The conflicting address.



Assertion

A kernel-side assertion.

Fields

condition: String

The assertion condition expression.

file: String

Source file name.

line: u32

Source line number.



Printf

A kernel-side printf invocation.

Fields

format: String

The format string.



Breakpoint

A breakpoint was hit.

Fields

id: u32

The breakpoint identifier.