CUmemPoolAttribute

Enum CUmemPoolAttribute 

#[non_exhaustive]
#[repr(u32)]
pub enum CUmemPoolAttribute { ReuseFollowEventDependencies = 1, ReuseAllowOpportunistic = 2, ReuseAllowInternalDependencies = 3, ReleaseThreshold = 4, ReservedMemCurrent = 5, ReservedMemHigh = 6, UsedMemCurrent = 7, UsedMemHigh = 8, }
Attribute discriminant for cuMemPoolSetAttribute / cuMemPoolGetAttribute.

Mirrors CUmemPoolAttribute in cuda.h. The numeric values match the CUDA header exactly so the enum can be passed straight to the driver.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ReuseFollowEventDependencies = 1

(value type = int) Allow reuse of memory still in use by an operation scheduled with an event dependency.



ReuseAllowOpportunistic = 2

(value type = int) Allow reuse of completed frees with no explicit event dependency (opportunistic reuse).



ReuseAllowInternalDependencies = 3

(value type = int) Allow the driver to insert internal stream dependencies to enable reuse.



ReleaseThreshold = 4

(value type = cuuint64_t) Amount of reserved memory (bytes) to hold onto before trying to release memory back to the OS.



ReservedMemCurrent = 5

(value type = cuuint64_t, read-only) Amount of backing memory currently allocated for the pool.



ReservedMemHigh = 6

(value type = cuuint64_t, read/write) High-water mark of backing memory allocated for the pool since the last reset.



UsedMemCurrent = 7

(value type = cuuint64_t, read-only) Amount of memory from the pool currently in use by the application.



UsedMemHigh = 8

(value type = cuuint64_t, read/write) High-water mark of memory in use from the pool since the last reset.