Safe wrappers for GPU memory information and bulk memory operations.
This module provides convenient functions for querying device memory usage and performing device-to-device copies and memsets.
Example
let (free, total) = memory_info::device_memory_info()?;
println!("GPU memory: {free} / {total} bytes free");Functions
- device_
memory_ info - Returns the amount of free and total device memory in bytes.
- memcpy_
device_ to_ device - Copies
bytesbytes from one device pointer to another. - memcpy_
device_ to_ device_ async - Asynchronously copies
bytesbytes from one device pointer to another. - memset_
d32 - Sets
count32-bit elements starting atptrtovalue. - memset_
d32_ async - Asynchronously sets
count32-bit elements starting atptrtovalue.