pub struct OccupancyGrid;Expand description
Sweep block sizes to find the configuration that maximises occupancy.
Implementations
Sourceimpl OccupancyGrid
impl OccupancyGrid
Sourcepub fn sweep(
calculator: &OccupancyCalculator,
registers_per_thread: u32,
shared_memory: u32,
) -> Vec<OccupancyPoint>
pub fn sweep( calculator: &OccupancyCalculator, registers_per_thread: u32, shared_memory: u32, ) -> Vec<OccupancyPoint>
Sweep block sizes from warp_size to max_threads_per_sm in
increments of warp_size and return occupancy at each step.
Sourcepub fn best_block_size(points: &[OccupancyPoint]) -> u32
pub fn best_block_size(points: &[OccupancyPoint]) -> u32
Pick the block size with the highest occupancy.
Ties are broken by choosing the smallest block size.
Returns 0 if the slice is empty.