pub struct StreamAllocation { /* private fields */ }Expand description
Handle to a stream-ordered memory allocation.
An allocation lives on the GPU and is associated with a specific stream and memory pool. It becomes available when all preceding work on the stream has completed, and is returned to the pool when freed (also stream-ordered).
Implementations